@@ -10,6 +10,7 @@
 ##' @examples
 ##' triagSize(1:5)
 ##' @export 
+
 triagSize <- function(diagSize){
     ((diagSize^2)-diagSize)/2+diagSize
 }
@@ -55,13 +56,8 @@ classify_matches <- function(matches,patterns) {
         ## if (grepl("^BLOCK\\(\\d+\\)$",match)) {
         if (grepl(use.pattern("block"),match)) {
             ## Extract the number from BLOCK(N)
-            
-            ## number <- as.numeric(str_match(match, "BLOCK\\((\\d+)\\)")[1, 2])
             if(grepl("\\( *(\\d+) *\\)",match)){
-                number <- ## as.numeric(
-                    ## stri_match_all_regex(match, "BLOCK\\s*\\( *(\\d+) *\\)")[[1]][1, 2]
-                    regmatches(match, regexec("BLOCK\\s*\\( *(\\d+) *\\)",match))[[1]][2]
-                ##)
+                number <- regmatches(match, regexec("BLOCK\\s*\\( *(\\d+) *\\)",match))[[1]][2]
             } else {
                 number <- "1"
             }
@@ -177,12 +173,12 @@ count_ij <- function(res){
         
         this.bsize <- 1
 
-        if(res[parnum==parcount,unique(inblock)==TRUE]){
+        if(res[parnum==parcount,unique(inblock)==TRUE&all(blocksize>1)]){
             ## assign i and j to all
             this.parblock <- res[parnum==parcount,unique(parblock)]
             this.res <- res[ parblock==this.parblock  & type.elem%in%c("init","lower","upper")]
             this.bsize <- this.res[,unique(blocksize)]
-
+            
             this.dt.ij <- data.table(parnum=parcount+seq(0,triagSize(this.bsize)-1),
                                      i=itriag(this.bsize,istart=icount),
                                      j=jtriag(this.bsize,istart=icount))
@@ -239,6 +235,7 @@ NMreadInits <- function(file,lines,section,return="pars",as.fun) {
     elem <- NULL
     elemnum <- NULL
     inblock <- NULL
+    isame <- NULL
     j <- NULL
     lastblockmax <- NULL
     linenum <- NULL
@@ -252,7 +249,13 @@ NMreadInits <- function(file,lines,section,return="pars",as.fun) {
     text.clean <- NULL
     type.elem <- NULL
     value.elem <- NULL
-    
+
+    if(missing(lines)) lines <- NULL
+    if(missing(file)) file <- NULL
+
+### this is assuming there is only one file, or that lines contains only one control stream.
+    lines <- getLines(file=file,lines=lines)
+
     if(missing(section)) section <- NULL
     if(is.null(section)) {
         section <- cc("theta","omega","sigma")
@@ -263,35 +266,37 @@ NMreadInits <- function(file,lines,section,return="pars",as.fun) {
     if(missing(as.fun)) as.fun <- NULL
     as.fun <- NMdataDecideOption("as.fun",as.fun)
 
-    section <- sub("\\$","",section)
+    section <- sub(" *\\$","",section)
     section <- cleanSpaces(section)
     section <- toupper(section)
+    section <- unique(section)
     
     ## if(length(section)>1) stop("Only one section can be handled at a time.")
     ## We want to keep everything, even empty lines so we can keep track of line numbers
     ## lines <- NMreadSection(lines=lines,section=section,keep.empty=TRUE,keep.comments=TRUE)
     ## if(length(lines)==0) return(NULL)
     
-    if(missing(lines)) lines <- NULL
-    if(missing(file)) file <- NULL
-### this is assuming there is only one file, or that lines contains only one control stream.
-    lines <- getLines(file=file,lines=lines)
-    
+
+    all.sections <- c("THETA","OMEGA","SIGMA","THETAP","THETAPV","OMEGAP","OMEGAPD","SIGMAP","SIGMAPD")
+    if(all(section=="ALL")){
+        section <- all.sections
+    }
     section <- unique(section)
-    if(!all(section%in%c("THETA","OMEGA","SIGMA"))) stop("section cannot be other than THETA, OMEGA and SIGMA.")
-
-
-#### these are the patterns used to identfy the different types of elements in parameter sections. It would be better to dfine them inside NMreadInits() and pass them to classify_matches.
-patterns <- 
-    c("block"="BLOCK\\s*(?:\\s*\\(\\d+\\s*\\))?",  # BLOCK(N)
-      "ll.init.ul"="\\(\\s*-?(?:\\d+(\\.\\d+)?|(?:\\d+)?\\.\\d+)([eE][+-]?\\d+)?\\s*,\\s*-?-?(?:\\d+(\\.\\d+)?|(?:\\d+)?\\.\\d+)([eE][+-]?\\d+)?\\s*,\\s*-?-?(?:\\d+(\\.\\d+)?|(?:\\d+)?\\.\\d+)([eE][+-]?\\d+)?\\s*\\)", # (ll,init,ul)
-      "ll.init"="\\(\\s*-?-?(?:\\d+(\\.\\d+)?|(?:\\d+)?\\.\\d+)([eE][+-]?\\d+)?\\s*,\\s*-?-?(?:\\d+(\\.\\d+)?|(?:\\d+)?\\.\\d+)([eE][+-]?\\d+)?\\s*\\)", # (ll,init)
-      "(init)"="\\(\\s*-?(?:\\d+(\\.\\d+)?|(?:\\d+)?\\.\\d+)([eE][+-]?\\d+)?\\s*\\)",  # (init)
-      "init" = "(?<!\\d)-?(\\d+\\.\\d+|\\d+\\.|\\.\\d+|\\d+)([eE][+-]?\\d+)?(?!\\.)",
-      "fix"="\\bFIX(ED)?\\b",  # FIX(ED)
-      "same"="SAME"
-      )
+    if(!all(section%in%all.sections)){
+        stop(sprintf("section cannot be other than %s",paste(all.sections,collapse=", ")))
+    }
 
+#### these are the patterns used to identfy the different types of elements in parameter sections. passed to classify_matches.
+    patterns <- 
+        c("block"="BLOCK\\s*(?:\\s*\\(\\d+\\s*\\))?",  # BLOCK(N)
+          ## "ll.init.ul"="\\(\\s*-?(?:\\d+(\\.\\d+)?|(?:\\d+)?\\.\\d+)([eE][+-]?\\d+)?\\s*,\\s*-?-?(?:\\d+(\\.\\d+)?|(?:\\d+)?\\.\\d+)([eE][+-]?\\d+)?\\s*,\\s*-?-?(?:\\d+(\\.\\d+)?|(?:\\d+)?\\.\\d+)([eE][+-]?\\d+)?\\s*\\)", # (ll,init,ul)
+          "ll.init.ul"="\\( *(\\s*-?(?:\\d+(\\.\\d+)?|(?:\\d+)?\\.\\d+)([eE][+-]?\\d+)?\\s*)*,\\s*-?-?(?:\\d+(\\.\\d+)?|(?:\\d+)?\\.\\d+)([eE][+-]?\\d+)?\\s*,( *\\s*-?-?(?:\\d+(\\.\\d+)?|(?:\\d+)?\\.\\d+)([eE][+-]?\\d+)?\\s*)*\\)", # (ll,init,ul)
+          "ll.init"="\\( *(\\s*-?-?(?:\\d+(\\.\\d+)?|(?:\\d+)?\\.\\d+)([eE][+-]?\\d+)?\\s*)*,\\s*-?-?(?:\\d+(\\.\\d+)?|(?:\\d+)?\\.\\d+)([eE][+-]?\\d+)?\\s*\\)", # (ll,init)
+          "(init)"="\\(\\s*-?(?:\\d+(\\.\\d+)?|(?:\\d+)?\\.\\d+)([eE][+-]?\\d+)?\\s*\\)",  # (init)
+          "init" = "(?<!\\d)-?(\\d+\\.\\d+|\\d+\\.|\\.\\d+|\\d+)([eE][+-]?\\d+)?(?!\\.)",
+          "fix"="\\bFIX(ED)?\\b",  # FIX(ED)
+          "same"="SAME"
+          )
     
     dt.lines <- rbindlist(
         lapply(section,function(sec){
@@ -301,25 +306,15 @@ patterns <-
                ,linenum:=.I][
                ,par.type:=sec]
             dt.l
-                        })
-,fill=TRUE
+        })
+       ,fill=TRUE
     )
     
     
     pattern <- paste(patterns,collapse="|")
 
-    
-    
-### dt.lines <- data.table(linenum=1:length(lines),text=lines)
-
     ## Preprocess to remove comments (everything after ";")
-    ## dt.lines[,text.after:=sub("^[^;]*;","",text)]
-    ## dt.lines[grepl(";", text),text.after:= gsub(";.*", "", text)]
     dt.lines[grepl(";", text),text.after:=sub("^[^;]*;","",text)]
-    ## dt.lines[is.na(text.after),text.after:=""]
-    
-    ## dt.lines[,text.before:=sub(paste0("(.*?)\\b(",patterns()[1],")\\b.*"),"\\1",text)]
-    ## dt.lines[,text.before:=sub(paste0("(.*?)\\b(",pattern,")\\b.*"),"\\1",text)]
     dt.lines[grepl(pattern,text,perl=TRUE),text.before:=sub(paste0("(.*?)(?:",pattern,").*"),"\\1",text,perl=TRUE)]
     ## dt.lines[is.na(text.before),text.before:=""]
 
@@ -334,7 +329,6 @@ patterns <-
 
     getMatches <- function(dt.lines){
         ## Function to classify matches and insert NA where applicable
-        
         text.clean <- NULL
         matches <- regmatches(dt.lines[,text.clean],gregexpr(pattern,dt.lines[,text.clean],perl=TRUE))
         
@@ -345,13 +339,11 @@ patterns <-
         })
         dt.match <- rbindlist(matches.list)
 
-        ## elemnum counts the fidings. It is an arbitrary counter because it groups (ll,init,ul) together but not FIX. It really can't be used for anything beyond this function so should not be exported.
+        ## elemnum counts the findings. It is an arbitrary counter because it groups (ll,init,ul) together but not FIX. It really can't be used for anything beyond this function so should not be exported.
         dt.match[,elemnum:=.I]
         dt.match
     }
 
-
-    
     dt.matches <- dt.lines[,getMatches(.SD),by=.(par.type)]
     
     res <- dt.matches[,classify_matches(string,patterns),by=.(par.type,linenum,elemnum)]
@@ -370,31 +362,53 @@ patterns <-
                 this.parnum <- this.parnum + 1
             }
             res[r,parnum:=this.parnum]
-            prev.type <- this.type
+            if(this.type!="FIX") {
+                ## if this type is FIX the type relevant for
+                ## classification hasn't changed from block, lower,
+                ## etc.
+                prev.type <- this.type
+            }
         }
         
-
         res[type.elem=="BLOCK",parblock:=as.integer(parnum)]
         res[type.elem=="BLOCK",blocksize:=as.integer(value.elem)]
         res[type.elem=="BLOCK",lastblockmax:=triagSize(blocksize)+parnum-1]
         res[,lastblockmax:=nafill(lastblockmax,type="locf")]
 
-
         res[,inblock:=FALSE]
         res[parnum<=lastblockmax,inblock:=TRUE]
         res[inblock==TRUE,blocksize:=nafill(blocksize,type="locf")]
         res[inblock==FALSE,blocksize:=1]
         res[inblock==TRUE,parblock:=nafill(parblock,type="locf")]
-
+        
+### If SAME and blocksize>1, element must be repeated for all block elements
+        res.sameblocks <- lapply(
+            split(res[value.elem=="SAME"&blocksize>1],by="elemnum")
+           ,
+            function(x){
+                newelems <- egdt(x,data.table(isame=1:triagSize(x$blocksize)),quiet=T)
+                newelems[,parnum:=parnum+isame-1]
+                newelems[,isame:=NULL]
+                newelems
+            }
+        )
+        res <- rbind(
+            res[!(value.elem=="SAME"&blocksize>1)]
+           ,
+            rbindlist(res.sameblocks)
+        )
+        setorder(res,elemnum)
+        
         res <- count_ij(res)
         res[,parblock:=NULL]
         ##res[,par.type:=section]
         res[par.type=="THETA",j:=NA]
         res
     })
-
+    
     res <- rbindlist(res.list)
     res <- addParameter(res)
+    setcolorder(res,c("parameter","par.name","par.type","i","j"))
     
     pars <- initsToExt(res)
     if(return=="pars") return(as.fun(pars))
@@ -410,6 +424,13 @@ patterns <-
 
 ##' Convert inits elements to a parameter data.frame
 ##' @param elements The elements object produced by `NMreadInits()`.
+##' @details initsToExt is misleading. It is not a reference to the
+##'     initstab, but actually the elements object returned by
+##'     NMreadInits. The elements object is more detailed as it
+##'     contains information about where information is found in
+##'     control stream lines. The `ext` object is a parameter
+##'     `data.frame`, same format as returned by
+##'     `NMdata::NMreadExt()`.
 ##' @import data.table
 ##' @keywords internal
 initsToExt <- function(elements){
@@ -421,7 +442,9 @@ initsToExt <- function(elements){
     FIX <- NULL
     iblock <- NULL
     init <- NULL
+    init.char <- NULL
     init.num <- NULL
+    init.num.tmp <- NULL
     i <- NULL
     j <- NULL
     lower <- NULL
@@ -429,19 +452,24 @@ initsToExt <- function(elements){
     par.type <- NULL
     parameter <- NULL
     par.name <- NULL
+    SAME <- NULL
     type.elem <- NULL
     
 ### Section end: Dummy variables, only not to get NOTE's in pacakge checks
     
-    pars <- dcast(elements[type.elem%in%cc(init,lower,upper,FIX)],par.type+i+j+iblock+blocksize~type.elem,value.var="value.elem")
+    pars <- dcast(elements[type.elem%in%cc(init,lower,upper,FIX)],parameter+par.name+par.type+i+j+iblock+blocksize~type.elem,value.var="value.elem")
 
+    setorder(pars,par.type,i,j)
 ###  init=SAME may not work for blocksizes>1
     if("init"%in%colnames(pars)){
-        
+        pars[,init.char:=init]
         suppressWarnings(pars[,init.num:=as.numeric(init)])
-        pars[!is.na(init.num)|init=="SAME",init.num:=nafill(init.num,type="locf")]
+        pars[,init.num.tmp:=nafill(init.num,type="locf")]
+        pars[!is.na(init.num)|init=="SAME",init.num:=init.num.tmp]
         pars[,init:=init.num]
         pars[,init.num:=NULL]
+        pars[,SAME:=0]
+        pars[init.char=="SAME",SAME:=1]
     } else {
         ## not sure this will ever happen
         pars[,init:=NA_real_]
@@ -450,19 +478,85 @@ initsToExt <- function(elements){
     pars[,FIX:=as.integer(FIX)]
     pars[is.na(FIX),FIX:=0L]
 
-    if(!"lower"%in% colnames(pars)) pars[,lower:=NA_real_]
+    if(!"lower"%in% colnames(pars)) pars[,lower:=NA_character_]
+    if(!"upper"%in% colnames(pars)) pars[,upper:=NA_character_]
     
-    if(!"upper"%in% colnames(pars)) pars[,upper:=NA_real_]
-    
-    pars[par.type=="THETA",parameter:=paste0(par.type,i)]
-    pars[par.type%in%c("OMEGA","SIGMA"),parameter:=sprintf("%s(%d,%d)",par.type,i,j)]
-    pars[,par.name:=parameter]
-    pars[par.type=="THETA",par.name:=sprintf("%s(%d)",par.type,i)]
+    pars <- addSameBlocks(pars)
+    cols <- c("parameter","par.name","par.type","i","j","iblock","blocksize","init","lower","upper","FIX","SAME","sameblock","Nsameblock")
+    cols <- intersect(cols,colnames(pars))
+    pars <- pars[,cols,with=FALSE]
 
-
-
-    pars <- pars[,.(par.type,parameter,par.name,i,j,iblock,blocksize,init,lower,upper,FIX)]
-    pars <- pars[order(match(par.type,c("THETA","OMEGA","SIGMA")),i,j)]
+    pars <- pars[
+        order(match(par.type,
+                    c("THETA","OMEGA","SIGMA","THETAP","THETAPV","OMEGAP","OMEGAPD","SIGMAP","SIGMAPD")) ,i,j)]
     
     pars[]
 }
+
+##' Create a variable in inital value table to keep track of SAME
+##' blocks i.e. parameters that are part of a single distribution
+##'
+##' @param inits Table of initial values as created by NMreadInits().
+##'
+##' @details
+##' sameblock:
+##'
+##' if not part of a distribution repeated using SAME: 0
+##'
+##' if part of a distribution repeated using SAME: counter (1,2,...)
+##' of the unique distribution blocks that are being reused.
+##'
+##' Nsameblock: The number of SAME calls used for a distribution
+##' block. If SAME(N) notation is used, Nsameblock=N.
+##' @author Brian Reilly
+##' @keywords internal
+
+addSameBlocks <- function(inits) {
+
+#### Section start: Dummy variables, only not to get NOTE's in pacakge checks ####
+
+    startSameBlock <- NULL
+    SAME <- NULL
+    endSameBlock <- NULL
+    Nsameblock <- NULL
+    sameblock <- NULL
+
+### Section end: Dummy variables, only not to get NOTE's in pacakge checks ####
+
+    inits = copy(as.data.table(inits))
+    inits[,startSameBlock := ifelse(SAME==0 & data.table::shift(SAME,type="lead") == 1, 1, 0)]
+    inits[,endSameBlock := ifelse(SAME==1 & data.table::shift(SAME,type="lead") == 0, 1, 0)]
+    df = inits
+    start <- as.integer(replace(df$startSameBlock, is.na(df$startSameBlock), 0))
+    end   <- as.integer(replace(df$endSameBlock,   is.na(df$endSameBlock),   0))
+    
+    ## allocate result and walk rows
+    df$sameblock <- 0L
+    block <- 0L
+    in_block <- FALSE
+    
+    for (i in seq_len(nrow(df))) {
+        if (start[i] == 1L) {
+            block <- block + 1L    # new block begins
+            in_block <- TRUE
+        }
+        
+        if (in_block) {
+            df$sameblock[i] <- block
+        } else {
+            df$sameblock[i] <- 0L  # or NA if you prefer
+        }
+        
+        if (end[i] == 1L) {
+                                        # end the current block after assigning this row
+            in_block <- FALSE
+        }
+    }
+    
+                                        # add N of same group
+    df[, Nsameblock := ifelse(any(sameblock!=0), .N-1, 0), by=sameblock]
+
+    df <- df[,setdiff(colnames(df),c("startSameBlock","endSameBlock")),with=FALSE]
+    
+    return(df[])
+}
