@@ -1,6 +1,6 @@
 library(devtools)
 
- load_all("~/wdirs/NMsim",export_all = FALSE)
+load_all("~/wdirs/NMsim",export_all = FALSE)
 library(NMsim)
 
 path.nonmem <- NMsim:::prioritizePaths(c(
@@ -18,3 +18,15 @@ NMexec("../nonmem/xgxr035.mod",method.execute = "NMsim",path.nonmem="/opt/NONMEM
 NMexec("../nonmem/xgxr044.mod",sge=F)
 
 NMexec("../nonmem/xgxr053.mod",sge=F)
+
+## PREDPP model
+NMexec("../nonmem/pred030.mod",sge=FALSE)
+
+## IGNORE on column with NA
+NMexec("../nonmem/xgxr054.mod",sge=FALSE)
+
+NMexec("../nonmem/xgxr055.mod",sge=FALSE)
+### dropping, then overwriting nomtime. using a new name in filters
+NMexec("../nonmem/xgxr056.mod",sge=FALSE)
+
+NMexec("../nonmem/xgxr059.mod",sge=FALSE)
