@@ -17,7 +17,7 @@ test_that("basic",{
     NMdataConf(as.fun="data.table")
 
     lines <- readLines(file.mod)
-    res1 <- NMreadInits(lines=lines,return="all")
+    res1  <- NMreadInits(lines=lines,return="all")
 
     ## res1$lines[grepl("^ +$",text.before),text.before:=""]
     res1$lines[,text.before:=""]
@@ -27,14 +27,23 @@ test_that("basic",{
 
     ## expect_equal_to_reference(res1,fileRef)
     expect_equal_to_reference(res1$pars,fnAppend(fileRef,"pars"))
+    if(F){
+        ref.pars <- readRDS(fnAppend(fileRef,"pars"))
+        ref.pars
+        res1$pars
+    }
+
     expect_equal_to_reference(res1$elements,fnAppend(fileRef,"elems"))
     expect_equal_to_reference(res1$lines,fnAppend(fileRef,"lines"))
 
 
     if(FALSE){
+
         ref.elems <- readRDS(fnAppend(fileRef,"elems"))
+        compareCols(ref.elems,res1$elements)
         ref.elems
         res1$elements
+
     }
     
 })
@@ -53,15 +62,22 @@ test_that("with OMEGA block",{
 
     ## expect_equal_to_reference(res1,fileRef)
     expect_equal_to_reference(res1$pars,fnAppend(fileRef,"pars"))
+    if(F){
+        ref.pars <- readRDS(fnAppend(fileRef,"pars"))
+        ref.pars
+        res1$pars
+    }
+
     expect_equal_to_reference(res1$elements,fnAppend(fileRef,"elems"))
     expect_equal_to_reference(res1$lines,fnAppend(fileRef,"lines"))
 
 
     if(FALSE){
         ref.elems <- readRDS(fnAppend(fileRef,"elems"))
+        compareCols(ref.elems,res1$elements)
         ref.elems
         res1$elements
-        ##expect_equal_to_reference(res1$elements[,!("parameter")],fnAppend(fileRef,"elems"))
+        ##expect_equal_to_reference(res1$elements[,!("parameter")],fnAppend(fileRef,"elems"))    
     }
 
 
@@ -88,6 +104,12 @@ $OMEGA  BLOCK(1) SAME")
 
     ## expect_equal_to_reference(res1,fileRef)
     expect_equal_to_reference(res1$pars,fnAppend(fileRef,"pars"))
+    if(F){
+        ref.pars <- readRDS(fnAppend(fileRef,"pars"))
+        ref.pars
+        res1$pars
+    }
+
     expect_equal_to_reference(res1$elements,fnAppend(fileRef,"elems"))
     expect_equal_to_reference(res1$lines,fnAppend(fileRef,"lines"))
 
@@ -96,8 +118,85 @@ $OMEGA  BLOCK(1) SAME")
         ref.elems <- readRDS(fnAppend(fileRef,"elems"))
         ref.elems
         res1$elements
+        compareCols(ref.elems,res1$elements)
         ##expect_equal_to_reference(res1$elements[,!("parameter")],fnAppend(fileRef,"elems"))
+
+        ref.pars <- readRDS(fnAppend(fileRef,"pars"))
+        compareCols(ref.pars,res1$pars)
+        ref.pars
+        res1$pars
     }
 
 
 })
+
+
+test_that("OMEGA BLOCK FIX 1",{
+    NMdataConf(reset=T)
+    NMdataConf(as.fun="data.table")
+
+    fileRef <- "testReference/NMreadInits_04.rds"
+    
+    text1 <- c("
+$THETA
+(0,0.1) ; THE1      - 30) 1st theta
+$OMEGA  BLOCK(2) 1 FIX  .3 ; first omega
+ 0.547465  ; IOV.TH1  ; 2 ;IOV
+")
+
+    text2 <- c("
+$THETA
+(0,0.1) ; THE1      - 30) 1st theta
+$OMEGA  BLOCK(2) FIX
+1 .3 ; first omega
+ 0.547465  ; IOV.TH1  ; 2 ;IOV
+")
+
+    ## options(warn=0)
+    res1 <- NMreadInits(lines=text1,return="all",as.fun="data.table")
+    res2 <- NMreadInits(lines=text2,return="all",as.fun="data.table")
+
+    ## res1$lines
+    ## res2$lines
+
+    expect_equal(res1$pars,
+                 res2$pars)
+    
+})
+
+
+test_that("BLOCK(2) SAME",{
+
+    fileRef <- "testReference/NMreadInits_05.rds"
+
+#### 
+
+    NMdataConf(reset=T)
+    NMdataConf(as.fun="data.table")
+
+
+    text <- c("
+$THETA
+(0,0.1) ;  1 ; 1st theta
+ (0,4.2) ; 2 ; 2nd theta
+$OMEGA  0.08   ;    IIV.TH1  ; 1  ;IIV
+;; A block(2) + SAME
+$OMEGA  BLOCK(2)
+ 0.547465  .01 .3     ; 2+3
+$OMEGA  BLOCK(2) SAME ; 4+5
+")
+    as.NMctl(text,lines=T)
+
+
+    res1  <- NMreadInits(lines=text,return="all")
+
+###  elemnum should not inc because there is only one observed element
+###  (SAME only written once in control stream)
+    res1
+
+    expect_equal_to_reference(res1$pars,
+                              fileRef)
+
+
+})
+
